# Redeye - Watching Redis

[![Build Status](https://travis-ci.org/spulec/redeye.png?branch=master)](https://travis-ci.org/spulec/moto)

# In a nutshell

```bash
$ redeye
```

## Install

```console
$ pip install redeye
```
